# -*- coding: utf-8 -*-
"""
@author: WYR。
"""
def add(x,y):
    return x+y

def division(x,y):
    return x/y

def mutiply(x,y):
    return x*y

def subtract(x,y):
    return x-y

def main():
    pass

if __name__ == '__main__':
    main()