# -*- coding: utf-8 -*-
"""
@author: WYR。
"""

from setuptools import setup

setup(
    name= 'package_wy',
    version= '1.0.0',
    packages = ['package_wy'],
    author='TuNan',
    author_email='wuuyanru@163.com',
    license='Apache',
)